@@ -1,16 +1,15 @@
 package AnyEvent::Retry::Interval::API;
 BEGIN {
-  $AnyEvent::Retry::Interval::API::VERSION = '0.01';
+  $AnyEvent::Retry::Interval::API::VERSION = '0.03';
 }
 # ABSTRACT: API role that interval classes must implement
 use Moose::Role;
+use true;
 use namespace::autoclean;
 
 requires 'next';
 requires 'reset';
 
-1;
-
 
 
 =pod
@@ -21,7 +20,7 @@ AnyEvent::Retry::Interval::API - API role that interval classes must implement
 
 =head1 VERSION
 
-version 0.01
+version 0.03
 
 =head1 SEE ALSO
 
